@@ -69,7 +69,7 @@ is used which in turn interfaces with the various formula classes.
 use Moose;
 extends 'GIS::Distance::Formula';
 
-use Class::Measure::Length;
+use Class::Measure::Length qw( length );
 use Math::Trig qw( deg2rad pi tan atan asin );
 
 =head1 METHODS
